@@ -15,9 +15,13 @@ from PyFin.api.DateUtilities import adjustDateByCalendar
 from PyFin.api.DateUtilities import advanceDateByCalendar
 from PyFin.api.DateUtilities import nthWeekDay
 
+from PyFin.api.Analysis import EMA
+from PyFin.api.Analysis import MACD
+from PyFin.api.Analysis import RSI
 from PyFin.api.Analysis import MA
 from PyFin.api.Analysis import MAX
 from PyFin.api.Analysis import MIN
+from PyFin.api.Analysis import VARIANCE
 from PyFin.api.Analysis import NPOSITIVE
 from PyFin.api.Analysis import MAPOSITIVE
 from PyFin.api.Analysis import HIST
@@ -37,9 +41,13 @@ __all__ = ["datesList",
            "adjustDateByCalendar",
            "advanceDateByCalendar",
            "nthWeekDay",
+           "EMA",
+           "MACD",
+           "RSI",
            "MA",
            "MAX",
            "MIN",
+           "VARIANCE",
            "NPOSITIVE",
            "MAPOSITIVE",
            "HIST",
